<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.audio-harvest.com
 * @since             1.0.0
 * @package           AudioHarvest
 *
 * @wordpress-plugin
 * Plugin Name:       AudioHarvest
 * Plugin URI:        https://www.audio-harvest.com
 * Description:       AudioHarvest - automatically convert website content into audio via our onsite audio player.
 * Version:           1.0.0
 * Author:            AudioHarvest
 * Author URI:        https://www.audio-harvest.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       audioharvest
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'AUDIOHARVEST_VERSION', '1.0.0' );

define('SHORTCODE_TAG', 'audioharvest-widget');
define('AUDIOHARVEST_WIDGET_CODE', '
<div id="audioharvest-widget">
  <script src="https://static.audio-harvest.com/widget/v3/widget.js"></script>
</div>');

// register_activation_hook( __FILE__, 'activate_audioharvest' );
// register_deactivation_hook( __FILE__, 'deactivate_audioharvest' );

/*
 * Shortcode below
 */
add_shortcode(SHORTCODE_TAG, 'audioharvest_shortcode');
function audioharvest_shortcode( $atts = [], $content = null) {
  return AUDIOHARVEST_WIDGET_CODE;
}

/*
 * Filter below
 */
add_filter( 'the_content', 'prepend_audioharvest_widget');
function prepend_audioharvest_widget( $content ) {
  if ( is_singular() && is_main_query() ) {
    return AUDIOHARVEST_WIDGET_CODE.$content;
  }

  return $content;
}

add_action("wp_head", "addStyle");
function addStyle(){
  $settings = array('backgroundcolor', 'foregroundcolor', 'progressBarColor', 'customColorEnable', 'bgOpacity', 'fgOpacity', 'pgOpacity');
  $dataSaved = array();
		foreach ($settings as $setting) {
			$dataSaved[$setting] = get_option('audio_harvest_setting_options-'.$setting);
		}
    $bgOpacity = isset($dataSaved['bgOpacity']) ? $dataSaved['bgOpacity'] : 1;
    $fgOpacity = isset($dataSaved['fgOpacity']) ? $dataSaved['fgOpacity'] : 1;
    $pgOpacity = isset($dataSaved['pgOpacity']) ? $dataSaved['pgOpacity'] : 1;
  if(isset($dataSaved['backgroundcolor']) && isset($dataSaved['foregroundcolor']) && isset($dataSaved['progressBarColor'])){
    $styling = "<style>
    #audioharvest-player-controls{
      background-color: ".$dataSaved['backgroundcolor']."!important;
      color: ".$dataSaved['foregroundcolor']."!important;
      opacity: ".$bgOpacity." !important;
    }
    #audioharvest-widget #current-time,
    #audioharvest-player-controls #current-time,
    #audioharvest-widget #audioharvest-promo a,
    #audioharvest-player-controls #audioharvest-promo a,
    #audioharvest-player-controls #total-duration,
    #audioharvest-widget #total-duration,
    #audioharvest-player-controls button#play-button,
    #audioharvest-widget button#play-button,
    #audioharvest-player-controls button#speed-button,
    #audioharvest-widget button#speed-button
    {
      color: ".$dataSaved['foregroundcolor']."!important;
      opacity: ".$fgOpacity." !important;
    }
    #audioharvest-widget #progress-bar-inner, #audioharvest-player-controls #progress-bar-inner{
      background-color:".$dataSaved['progressBarColor']."!important;
      opacity: ".$pgOpacity." !important;
    }
    </style>
    ";
    if(isset($dataSaved['customColorEnable']) && $dataSaved['customColorEnable'] == "on"){
      echo $styling;
    }
  }
}

add_action("wp_head", "addCustomStyle");
function addCustomStyle(){
  $settings = array('styling');
  $dataSaved = array();
		foreach ($settings as $setting) {
			$dataSaved[$setting] = get_option('audio_harvest_setting_options-'.$setting);
		}
  
  if($dataSaved['styling'] && strlen($dataSaved['styling']) > 0){
    $dataSaved['styling'] = stripslashes($dataSaved['styling']);
  }
  if(isset($dataSaved['styling'])){
    echo "<style>".$dataSaved['styling']."</style>";
  }
}

add_action( 'admin_menu', 'audio_harvest_menu' );

function audio_harvest_menu(){
  add_management_page(
      'Audio Harvest Settings', 
      'Audio Harvest Settings', 
      'edit_posts', 
      'audio_harvest_settings', 
      'audio_harvest_setting_function',
      'dashicons-media-spreadsheet',
      100
    );
}

function audio_harvest_setting_function(){
  $settings = array('backgroundcolor', 'bgOpacity', 'foregroundcolor', 'fgOpacity', 'progressBarColor', 'pgOpacity', 'styling', 'customColorEnable');
		if ( isset( $_REQUEST['page'] ) && $_REQUEST['page'] == 'audio_harvest_settings' && isset($_REQUEST['audio_harvest_settings_save']) ) {
			echo '<div class="is-dismissible notice"><p>Settings saved successfully.</p></div>';
			foreach ($settings as $setting) {
        // if(isset($_REQUEST['styling'])){
        //   $_REQUEST['styling'] = base64_encode( trim( $_REQUEST['styling'] ) );
        // }
				if(isset($_REQUEST[$setting])){
					update_option('audio_harvest_setting_options-'.$setting, $_REQUEST[$setting]);
				}
			}
      if(!isset($_REQUEST['customColorEnable'])){
        update_option('audio_harvest_setting_options-customColorEnable', "off");
      }
		}
    $dataSaved = array();
		foreach ($settings as $setting) {
			$dataSaved[$setting] = get_option('audio_harvest_setting_options-'.$setting);
		}
    if($dataSaved['styling'] && strlen($dataSaved['styling']) > 0){
      $dataSaved['styling'] = stripslashes($dataSaved['styling']);
    }
    $classtr = "affectStyle";
    if(!isset($dataSaved['customColorEnable'])){
      $classtr .= " disabled";
    } elseif(isset($dataSaved['customColorEnable']) && $dataSaved['customColorEnable'] == "off"){
      $classtr .= " disabled";
    }
    ?>
    <script>
      function updateColorAlpha(value, element){
        document.getElementById(element).style.opacity=value;
      }
    </script>
    <div class="wrap">
      <h1>Audio Harvest Settings</h1>
      <p>Note that in order for the <a href="https://www.audio-harvest.com">AudioHarvest</a> player to appear on your blog posts, the corresponding
      posts should be published on your AudioHarvest account.<br/>
      You can sign up for an always free service account at <a href="https://onboard.audio-harvest.com">https://onboard.audio-harvest.com</a> .<br/>
      The account will automatically capture the content from the users website that the user can then select for the automatic deployment of the onsite audio player.</p>
      <form method="post">
				<table class="form-table">
          <tr>
						<th>
							<label for="color">Enable Color Customization</label>
						</th>
						<td>
							<input id="enableCustomization" type="checkbox" value="on" name="customColorEnable" <?php echo isset($dataSaved['customColorEnable']) ? $dataSaved['customColorEnable'] == 'on' ? 'checked' : '' : ''; ?>>
							<span class="description">Check On if you want to customize the players colors.</span>
						</td>
					</tr>
          <tr class="<?php echo $classtr; ?>">
						<th>
							<label for="color">Player Background color</label>
						</th>
						<td>
							<input type="color" id="backgroundcolor" name="backgroundcolor" value="<?php echo isset($dataSaved['backgroundcolor']) ? $dataSaved['backgroundcolor'] : ''; ?>">
							<input name="bgOpacity" class="range" type="range" min="0" max="1" step="0.1" value="<?php echo isset($dataSaved['bgOpacity']) ? $dataSaved['bgOpacity'] : 1;?>" onchange="updateColorAlpha(this.value, 'backgroundcolor');"><br/>
              <span class="description">Select the color you want to apply on player's background with slider to control the transparency.</span>
              
						</td>
					</tr>
					<tr class="<?php echo $classtr; ?>">
						<th>
							<label for="color">Player Foreground color</label>
						</th>
						<td>
							<input type="color" name="foregroundcolor" id="foregroundcolor" value="<?php echo isset($dataSaved['foregroundcolor']) ? $dataSaved['foregroundcolor'] : ''; ?>">
              <input type="hidden" name="audio_harvest_settings_save">
              <input name="fgOpacity" class="range" type="range" min="0" max="1" step="0.1" value="<?php echo isset($dataSaved['fgOpacity']) ? $dataSaved['fgOpacity'] : 1;?>" onchange="updateColorAlpha(this.value, 'foregroundcolor');"><br/>
							<span class="description">Select the color you want to apply on player's foreground with slider to control the transparency.</span>
						</td>
					</tr>
					<tr class="<?php echo $classtr; ?>">
						<th>
							<label for="color">ProgressBar color</label>
						</th>
						<td>
							<input type="color" name="progressBarColor" id="progressBarColor" value="<?php echo isset($dataSaved['progressBarColor']) ? $dataSaved['progressBarColor'] : ''; ?>">
              <input name="pgOpacity" class="range" type="range" min="0" max="1" step="0.1" value="<?php echo isset($dataSaved['pgOpacity']) ? $dataSaved['pgOpacity'] : 1;?>" onchange="updateColorAlpha(this.value, 'progressBarColor');"><br/>
							<span class="description">Select the color you want to apply on player's progressbar with slider to control the transparency.</span>
						</td>
					</tr>
          <tr>
						<th>
							<label for="styling">Extra CSS Styling</label>
						</th>
						<td>
							<textarea name="styling" id="styling" cols="60" rows="7"><?php echo isset($dataSaved['styling']) ? $dataSaved['styling'] : '';?></textarea><br>
							<span class="description">Custom CSS styling you can add here</span>
						</td>
					</tr>
        </table>
        <?php echo submit_button(); ?>
      </form>
    </div>

    <script>
      jQuery(document).ready(function(){
        jQuery('#enableCustomization').on('change',function(e){
          if(this.checked){
            jQuery(".affectStyle").removeClass("disabled");
          } else {
            jQuery(".affectStyle").addClass("disabled");
          }
        });
        jQuery('input.range').trigger("change",true);
      });
    </script>
    <style>
      .affectStyle.disabled{
        pointer-events:none;
        opacity:0.6;
      }
      input.range{
        margin-top:10px;
      }
    </style>
    <?php
}
